import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;

/**
 * Test XrppParser mit pricelist_empty_elem.xml .
 * 
 * @author Heiner Kcker
 */
public class TestPricelistEmptyElementXml
{

  /**
   * Test.
   * 
   * @param args
   * @throws IOException
   * @throws XrppParseException
   * @throws Exception
   */
  public static void main(
      String[] args )
      throws IOException ,
      XrppParseException ,
      Exception
  {
    final String workDir = System.getProperty( "user.dir" ); // user.home
    final String xmlFileName = "pricelist_empty_elem.xml";
    final String xmlFileNameAndPath = workDir
        + File.separator + xmlFileName;
    final File xmlFile = new File( xmlFileNameAndPath );
    final FileInputStream fileInStream = new FileInputStream( xmlFile );
    final MultiMarkableBufferedInputStream buffInStream = new MultiMarkableBufferedInputStream( fileInStream );

    final XrppParser parser = new XrppParser( buffInStream );

    try
    {
      parse( parser );
    }
    catch (Exception e)
    {
      System.out.println( buffInStream );
      throw e;
    }
    buffInStream.close();
  }

  /**
   * parse
   * 
   * @param pBuffInStream
   * @throws XrppParseException
   * @throws IOException
   */
  private static final void parse(
      final XrppParser parser )
      throws IOException ,
      XrppParseException
  {
    parser.skipXmlDeclaration();

    parser.skipDoctypeDeclaration();

    parser.forceElementStart( "xbe:price-list".getBytes() );

    parser.getAttribute( "xmlns:xbe".getBytes() );

    parser.forceElementBody();
    {
      parser.getElementBodyWithStartAndEndTag( "xbe:name".getBytes() );

      while (parser.isElementStart( "xbe:vendor".getBytes() ))
      {
        parser.forceElementStart( "xbe:vendor".getBytes() );
        if ( parser.isElementEmpty() )
        {
          parser.forceElementStopEmpty();
          continue;
        }
        
        parser.forceElementBody();

        parser.getOptionalElementBody( "xbe:name".getBytes() );

        while (parser.isElementStart( "xbe:price-quote".getBytes() ))
        {
          parser.forceElementStart( "xbe:price-quote".getBytes() );

          parser.getAttribute( "delivery".getBytes() );

          parser.getElementBodyWithoutStart( "xbe:price-quote".getBytes() );
        }
        parser.forceElementStopNoEmpty( "xbe:vendor".getBytes() );
      }

    }
    parser.forceElementStopNoEmpty( "xbe:price-list".getBytes() );

    parser.checkForEndOfDocument();

    System.out.println( "ok" );
  }

}
