import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;

/**
 * Test XrppParser mit rss.xml .
 * 
 * @author Heiner Kcker
 */
public class TestRssXml
{

  /**
   * Test.
   * 
   * @param args
   * @throws IOException
   * @throws XrppParseException
   * @throws Exception
   */
  public static void main(
      String[] args )
      throws IOException ,
      XrppParseException ,
      Exception
  {
    final String workDir = System.getProperty( "user.dir" ); // user.home
    final String xmlFileName = "rss.xml";
    final String xmlFileNameAndPath = workDir
        + File.separator + xmlFileName;
    final File xmlFile = new File( xmlFileNameAndPath );
    final FileInputStream fileInStream = new FileInputStream( xmlFile );
    final MultiMarkableBufferedInputStream buffInStream = new MultiMarkableBufferedInputStream( fileInStream );

    final XrppParser parser = new XrppParser( buffInStream );

    try
    {
      parse( parser );
    }
    catch (Exception e)
    {
      System.out.println( buffInStream );
      throw e;
    }
    buffInStream.close();
  }

  /**
   * parse
   * 
   * @param pBuffInStream
   * @throws XrppParseException
   * @throws IOException
   */
  private static final void parse(
      final XrppParser parser )
      throws IOException ,
      XrppParseException
  {
    parser.skipXmlDeclaration();

    parser.skipDoctypeDeclaration();

    parser.forceElementStart( "rss".getBytes() );

    parser.getAttribute( "version".getBytes() );

    parser.forceElementBody();
    {
      parser.forceElementStart( "channel".getBytes() );
      parser.forceElementBody();
      {
        parser.getElementBodyWithStartAndEndTag( "title".getBytes() );
        parser.getElementBodyWithStartAndEndTag( "link".getBytes() );
        parser.getElementBodyWithStartAndEndTag( "description".getBytes() );
        parser.getElementBodyWithStartAndEndTag( "language".getBytes() );
        parser.getElementBodyWithStartAndEndTag( "copyright".getBytes() );
        parser.getElementBodyWithStartAndEndTag( "managingEditor".getBytes() );
        parser.getElementBodyWithStartAndEndTag( "webMaster".getBytes() );

        parser.forceElementStart( "image".getBytes() );
        parser.forceElementBody();
        {
          parser.getElementBodyWithStartAndEndTag( "title".getBytes() );
          parser.getElementBodyWithStartAndEndTag( "url".getBytes() );
          parser.getElementBodyWithStartAndEndTag( "link".getBytes() );
          parser.getElementBodyWithStartAndEndTag( "width".getBytes() );
          parser.getElementBodyWithStartAndEndTag( "height".getBytes() );
          parser.getElementBodyWithStartAndEndTag( "description".getBytes() );
        }
        parser.forceElementStopNoEmpty( "image".getBytes() );

        while (parser.isElementStart( "item".getBytes() ))
        {
          parser.forceElementStart( "item".getBytes() );
          parser.forceElementBody();
          parser.getElementBodyWithStartAndEndTag( "title".getBytes() );
          parser.getElementBodyWithStartAndEndTag( "link".getBytes() );
          parser.getElementBodyWithStartAndEndTag( "description".getBytes() );
          parser.forceElementStopNoEmpty( "item".getBytes() );
        }

      }
      parser.forceElementStopNoEmpty( "channel".getBytes() );
    }
    parser.forceElementStopNoEmpty( "rss".getBytes() );

    parser.checkForEndOfDocument();
    
    System.out.println( "ok" );
  }

}
